Using Macros
============

Macros are special kinds of plugins that perform simple functions for
transforming text you enter into fields into something else when
submitting them to JIRA.

Existing Macros
---------------

* `jirafs-list-table <https://github.com/coddingtonbear/jirafs-list-table>`_: 
  Make JIRA tables a little more easily by using a simple list-based syntax.

Writing your own Macros
-----------------------

Macros are really just special kinds of plugins; you can find more information
about writing your own plugins in :ref:`macro_plugins`.
